@@ -55,6 +55,12 @@
 #define	MAX_LIST	256
 #define	MAX_LIBINPUT	256
 
+#ifdef	WIN32
+#define	PFD_INVALID	INVALID_HANDLE_VALUE
+#else
+#define	PFD_INVALID	-1
+#endif
+
 namespace ost {
 
 class __EXPORT BayonneMsgport;
@@ -63,7 +69,7 @@ class __EXPORT BayonneSession;
 class __EXPORT BayonneSpan;
 class __EXPORT BayonneService;
 class __EXPORT BayonneTranslator;
-
+	  
 /**
  * Generic Bayonne master class to reference various useful data types
  * and core static members used for locating resources found in libbayonne.
@@ -181,6 +187,7 @@ public:
 		STATE_START,
 		STATE_HANGUP,
 		STATE_LIBRESET,
+		STATE_WAITKEY,
 		STATE_FINAL,
 
 		STATE_STANDBY = STATE_DOWN,
@@ -288,11 +295,16 @@ public:
 		EXIT_LIBEXEC,
 		HEAD_LIBEXEC,
 		ARGS_LIBEXEC,
-		VAR_LIBEXEC,
-		GET_LIBEXEC,
+		GOT_LIBEXEC,
+		READ_LIBEXEC,
 		DROP_LIBEXEC,
 		STAT_LIBEXEC,
 		PROMPT_LIBEXEC,
+		CLEAR_LIBEXEC,
+		WAIT_LIBEXEC,
+		RECORD_LIBEXEC,
+		REPLAY_LIBEXEC,
+		RESTART_LIBEXEC,
 
 		// primary driver events
 
@@ -411,11 +423,12 @@ public:
 
 	typedef	enum
 	{
-		RESULT_SUCCESS,
+		RESULT_SUCCESS = 0,
 		RESULT_TIMEOUT,
 		RESULT_INVALID,
 		RESULT_PENDING,
 		RESULT_COMPLETE,
+		RESULT_FAILED,
 	}	result_t;
 
 	typedef	struct
@@ -455,33 +468,14 @@ public:
 			struct
 			{
 				const char *tid;
+#ifdef	WIN32
+				HANDLE	pfd;
+#else
 				const char *fname;
+#endif
 				int pid, result;
 			}	libexec;
 
-			struct
-			{
-				const char *tid;
-				const char *name;
-				const char *value;
-				int size;
-			}	varexec;
-
-			struct
-			{
-				const char *tid;
-				timeout_t timeout;
-				unsigned count;
-				const char *exit;
-			}	libinput;
-
-			struct
-			{
-				const char *tid;
-				const char *voice;
-				const char *text;
-			}	libprompt;
-
 			struct
 			{
 				timeout_t duration;
@@ -547,7 +541,11 @@ public:
 		Name *menu;
 		unsigned stack;
 		Line *lib;
+#ifdef	WIN32
+		HANDLE pfd;
+#else
 		int pfd;
+#endif
 		result_t result;
 		int pid;
 		libaudio_t *libaudio;
@@ -1655,6 +1653,7 @@ protected:
 	bool stateRunning(Event *event);
 	bool stateLibexec(Event *event);
 	bool stateLibreset(Event *event);
+	bool stateWaitkey(Event *event);
 	bool stateThreading(Event *event);
 	bool stateHangup(Event *event);
 	bool stateCollect(Event *event);
@@ -1680,6 +1679,19 @@ protected:
 	 */
 	bool putEvent(Event *event);
 
+	/**
+	 * Write libexec...
+	 *
+	 * @param string to write.
+	 */
+	void libWrite(const char *str);
+
+	void libClose(const char *str);
+
+	bool isLibexec(const char *tsid);
+
+	timeout_t getLibexecTimeout(void);
+
 public:
 	/**
 	 * Process interpreter session symbols.
